package com.reign.gcld.yx.common;

import com.reign.framework.netty.mvc.result.ByteResult;
import com.reign.framework.netty.servlet.Request;
import com.reign.framework.netty.servlet.Session;
import com.reign.gcld.activity.service.IActivityService;
import com.reign.gcld.chat.dao.ISilenceDao;
import com.reign.gcld.chat.domain.Silence;
import com.reign.gcld.common.Constants;
import com.reign.gcld.common.Players;
import com.reign.gcld.common.TimeUtil;
import com.reign.gcld.common.Users;
import com.reign.gcld.common.log.Logger;
import com.reign.gcld.common.util.WebUtil;
import com.reign.gcld.common.web.AuthInterceptor;
import com.reign.gcld.log.ErrorLogger;
import com.reign.gcld.notice.dao.ISystemNoticeDao;
import com.reign.gcld.notice.domain.SystemNotice;
import com.reign.gcld.pay.dao.IPlayerPayDao;
import com.reign.gcld.pay.domain.PlayerPay;
import com.reign.gcld.pay.service.IPayService;
import com.reign.gcld.player.dao.IPlayerAttributeDao;
import com.reign.gcld.player.dao.IPlayerDao;
import com.reign.gcld.player.dao.IPlayerResourceDao;
import com.reign.gcld.player.dao.IPlayerTaobaoDao;
import com.reign.gcld.player.domain.Player;
import com.reign.gcld.player.domain.PlayerAttribute;
import com.reign.gcld.player.domain.PlayerTaobao;
import com.reign.gcld.player.dto.PlayerDto;
import com.reign.gcld.user.dao.IUserBlockDao;
import com.reign.gcld.user.dao.IUserDao;
import com.reign.gcld.user.domain.User;
import com.reign.gcld.user.domain.UserBlock;
import com.reign.gcld.user.dto.UserDto;
import com.reign.plugin.yx.PluginContext;
import com.reign.plugin.yx.common.BackstageUtil;
import com.reign.plugin.yx.common.IYxOperation;
import com.reign.plugin.yx.common.OpLogUtil;
import com.reign.plugin.yx.common.PingAnMoneyInfo;
import com.reign.plugin.yx.common.PingAnPlayerInfo;
import com.reign.plugin.yx.common.WebUtils;
import com.reign.plugin.yx.common.YxHelper;
import com.reign.plugin.yx.common.YxNoticeInfo;
import com.reign.plugin.yx.common.YxPlayerInfo;
import com.reign.plugin.yx.common.YxPlayerPayInfo;
import com.reign.plugin.yx.common.YxSourceInfo;
import com.reign.plugin.yx.common.YxTencentPayInfo;
import com.reign.plugin.yx.common.YxTencentUserInfo;
import com.reign.plugin.yx.common.YxUserInfo;
import com.reign.plugin.yx.util.Coder;
import com.reign.plugin.yx.util.HMAC_SHA1;
import com.reign.util.Tuple;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component("yxOperation")
public class YxOperation implements IYxOperation {
   @Autowired
   private IPlayerDao playerDao;
   @Autowired
   private IUserDao userDao;
   @Autowired
   private IPayService payService;
   @Autowired
   private IPlayerPayDao playerPayDao;
   @Autowired
   private ISilenceDao silenceDao;
   @Autowired
   private IUserBlockDao userBlockDao;
   @Autowired
   private ISystemNoticeDao systemNoticeDao;
   @Autowired
   private IPlayerResourceDao playerResourceDao;
   @Autowired
   private IPlayerTaobaoDao playerTaobaoDao;
   @Autowired
   private IActivityService activityService;
   @Autowired
   private IPlayerAttributeDao playerAttributeDao;
   private static final Logger errorLog = new ErrorLogger();
   private static final Log opReport = LogFactory.getLog("com.reign.gcld.opreport");
   private int TEN_YEARS_HOURS = 87600;
   private static Map<String, YxTencentPayInfo> tencentPayMap = new ConcurrentHashMap();
   public static final String yxPengyou = "pengyou";
   public static final String yxQzone = "qzone";
   public static final String yx3366 = "3366";
   private static final int WXIN_REWARD_NUMBER = 20000;

   public Session login(String yx, String userId, String userName, String sfid, String adult, String yxSource, Request request) {
      UserDto dto = new UserDto();
      dto.userId = userId;
      dto.userName = userName;
      dto.loginTime = System.currentTimeMillis();
      dto.yx = yx;
      dto.setYxSource(yxSource);
      dto.firstLogin = this.playerDao.getRoleCount(userId, yx) <= 0;
      User user = this.userDao.getUserByUserName(userName);
      if (user == null) {
         user = new User();
         user.setUserName(userName);
         user.setAdult(1);
         user.setPassword(userId);
         user.setActivate(1);
         user.setActivateCode((String)null);
         user.setRewardForce(0);
         this.userDao.create(user);
      }

      if (WebUtil.needAntiAddiction(yx) && "0".equals(adult)) {
         dto.setNeedAntiAddiction(true);
      } else {
         dto.setNeedAntiAddiction(false);
      }

      Session session = request.getNewSession();
      session.setAttribute("user", dto);
      List<Player> players = this.playerDao.getPlayerNoDeleteByUserIdAndYx(userId, yx);
      if (players != null && players.size() > 0) {
         Player p = (Player)players.get(0);
         PlayerDto pdto = new PlayerDto();
         pdto.playerId = p.getPlayerId();
         pdto.playerName = p.getPlayerName();
         pdto.playerLv = p.getPlayerLv();
         pdto.loginTime = dto != null ? dto.loginTime : System.currentTimeMillis();
         pdto.userId = userId;
         pdto.yx = yx;
         pdto.forceId = p.getForceId();
         pdto.consumeLv = p.getConsumeLv();
         pdto.yxSource = p.getYxSource();
         PlayerAttribute pa = this.playerAttributeDao.read(p.getPlayerId());
         char[] cs = pa.getFunctionId().toCharArray();
         pdto.cs = cs;
         pdto.gm = p.getGm();
         session.setAttribute("PLAYER", pdto);
      }

      return session;
   }

   public Session loginForTencent(String yx, String adult, String yxSource, YxTencentUserInfo ytuInfo, Request request) {
      UserDto dto = new UserDto();
      dto.userId = ytuInfo.getUserId();
      dto.userName = ytuInfo.getUserName();
      dto.loginTime = System.currentTimeMillis();
      dto.yx = yx;
      dto.setYxSource(yxSource);
      dto.setOpenId(ytuInfo.getOpenId());
      dto.setOpenKey(ytuInfo.getOpenKey());
      dto.setIsYellowVip(ytuInfo.getIsYellowVip());
      dto.setYellowVipLevel(ytuInfo.getYellowVipLevel());
      dto.setIsYellowHighVip(ytuInfo.getIsYellowHighVip());
      dto.setIsYellowYearVip(ytuInfo.getIsYellowYearVip());
      dto.setPf(ytuInfo.getPf());
      dto.setPfKey(ytuInfo.getPfKey());
      dto.setUserIp(ytuInfo.getUserIp());
      dto.firstLogin = this.playerDao.getRoleCountByUid(dto.userId) <= 0;
      if (WebUtil.needAntiAddiction(yx) && "0".equals(adult)) {
         dto.setNeedAntiAddiction(true);
      } else {
         dto.setNeedAntiAddiction(false);
      }

      Session session = request.getNewSession();
      session.setAttribute("user", dto);
      return session;
   }

   public Tuple<Integer, Integer> pay(String orderId, int playerId, String userId, String yx, int gold, Request request) {
      Tuple<Integer, Integer> tuple = new Tuple();
      if (playerId <= 0) {
         playerId = this.getDefaultPayPlayer(userId, yx);
      }

      Player player = this.playerDao.read(playerId);
      if (player == null) {
         tuple.left = 2;
         tuple.right = 2;
         return tuple;
      } else {
         if (this.checkTencentPf(yx) && !player.getYx().equals(yx)) {
            yx = player.getYx();
         }

         if (player.getUserId().equalsIgnoreCase(userId) && player.getYx().equals(yx)) {
            label126: {
               Tuple var10;
               try {
                  Constants.locks[playerId % Constants.LOCKS_LEN].lock();
                  if (this.playerPayDao.containsOrderId(orderId, yx)) {
                     tuple.left = 5;
                     tuple.right = 5;
                     var10 = tuple;
                     Tuple var10 = var10;
                     return var10;
                  }

                  if (this.payService.commonPay(orderId, gold, userId, yx, 0, "充值获得金币", player, new Date(), player.getYxSource(), request)) {
                     break label126;
                  }

                  tuple.left = 1000;
                  tuple.right = 1000;
                  var10 = tuple;
               } finally {
                  Constants.locks[playerId % Constants.LOCKS_LEN].unlock();
               }

               return var10;
            }

            Exception var14;
            try {
               this.payService.addAdditionalGold(playerId, gold);
            } catch (Exception var16) {
               var14 = var16;
               errorLog.error("#pay_activity_error#orderId#" + orderId + "#playerId#" + playerId + "#userId#" + userId + "#gold#" + gold + "#");
               errorLog.error("#pay_activity_error#orderId#" + orderId + "#playerId#" + playerId + "#userId#" + userId + "#gold#" + gold + "#", var14);
            }

            try {
               this.payService.addTicketGold(playerId, gold);
            } catch (Exception var15) {
               var14 = var15;
               errorLog.error("#pay_ticket_activity_error#orderId#" + orderId + "#playerId#" + playerId + "#userId#" + userId + "#gold#" + gold + "#");
               errorLog.error("#pay_ticket_activity_error#orderId#" + orderId + "#playerId#" + playerId + "#userId#" + userId + "#gold#" + gold + "#", var14);
            }

            tuple.left = 1;
            tuple.right = 1;
            return tuple;
         } else {
            tuple.left = 3;
            tuple.right = 3;
            return tuple;
         }
      }
   }

   public List<YxPlayerInfo> queryPlayer(String userId, String yx) {
      List<Player> players = this.playerDao.getPlayerNoDeleteByUserIdAndYx(userId, yx);
      List<YxPlayerInfo> playerList = new ArrayList();
      Iterator var6 = players.iterator();

      while(var6.hasNext()) {
         Player player = (Player)var6.next();
         YxPlayerInfo ypi = new YxPlayerInfo(player.getPlayerId(), player.getPlayerName(), player.getState(), player.getPlayerLv(), player.getForceId(), userId, player.getCreateTime());
         playerList.add(ypi);
      }

      return playerList;
   }

   public YxPlayerInfo queryPlayer(String userId, String yx, String playerName) {
      Player player = this.playerDao.queryPlayer(userId, yx, playerName);
      if (player == null) {
         return null;
      } else {
         YxPlayerInfo ypi = new YxPlayerInfo(player.getPlayerId(), player.getPlayerName(), player.getState(), player.getPlayerLv(), player.getForceId(), userId, player.getCreateTime());
         return ypi;
      }
   }

   public YxPlayerInfo queryPlayerByPlayerNameAndYx(String playerName, String yx) {
      Player player = this.playerDao.getPlayerByNameAndYx(playerName, yx);
      if (player == null) {
         return null;
      } else {
         YxPlayerInfo ypi = new YxPlayerInfo(player.getPlayerId(), player.getPlayerName(), player.getState(), player.getPlayerLv(), player.getForceId(), player.getUserId(), player.getCreateTime());
         return ypi;
      }
   }

   public List<YxPlayerPayInfo> queryPlayerPayDetails(String yx, String userId, int playerId) {
      List<YxPlayerPayInfo> playerPayList = new ArrayList();
      List<PlayerPay> payList = this.playerPayDao.getPlayerPayByPlayerId(playerId);
      Iterator var7 = payList.iterator();

      while(var7.hasNext()) {
         PlayerPay p = (PlayerPay)var7.next();
         if (p.getYx().equals(yx) && p.getUserId().equals(userId)) {
            YxPlayerPayInfo ppi = new YxPlayerPayInfo(userId, p.getOrderId(), p.getGold(), p.getType(), p.getCreateTime(), p.getPlayerId());
            playerPayList.add(ppi);
         }
      }

      return playerPayList;
   }

   public YxUserInfo getYxUserInfo(Request request) {
      Object obj = request.getSession().getAttribute("user");
      if (obj != null && obj instanceof UserDto) {
         UserDto dto = (UserDto)obj;
         return new YxUserInfo(dto.userId, dto.userName);
      } else {
         return null;
      }
   }

   public YxPlayerInfo getYxPlayerInfo(Request request) {
      PlayerDto dto = Players.getSession(request.getSession().getId());
      return dto == null ? null : new YxPlayerInfo(dto.playerId, dto.playerName, 0, dto.playerLv, dto.forceId, dto.userId, dto.createTime);
   }

   public int getDefaultPayPlayer(String userId, String yx) {
      return this.playerDao.getDefaultPlayerId(userId, yx);
   }

   public YxPlayerInfo getDefaultPayPlayer(Request request) {
      Object obj = request.getSession().getAttribute("user");
      if (obj != null && obj instanceof UserDto) {
         UserDto dto = (UserDto)obj;
         int playerId = this.getDefaultPayPlayer(dto.userId, dto.yx);
         if (playerId <= 0) {
            return null;
         } else {
            Player player = this.playerDao.read(playerId);
            return new YxPlayerInfo(playerId, player.getPlayerName(), player.getState(), player.getPlayerLv(), player.getForceId(), player.getUserId(), player.getCreateTime());
         }
      } else {
         return null;
      }
   }

   public List<YxPlayerPayInfo> queryYxPayDetails(String yx, Date startTime, Date endTime) {
      List<YxPlayerPayInfo> playerPayList = new ArrayList();
      List<PlayerPay> payList = this.playerPayDao.getPlayerPayByDateAndYx(startTime, endTime, yx);
      Iterator var7 = payList.iterator();

      while(var7.hasNext()) {
         PlayerPay p = (PlayerPay)var7.next();
         YxPlayerPayInfo ppi = new YxPlayerPayInfo(p.getUserId(), p.getOrderId(), p.getGold(), p.getType(), p.getCreateTime(), p.getPlayerId());
         playerPayList.add(ppi);
      }

      return playerPayList;
   }

   public List<YxSourceInfo> queryPlayerYxSource(String yx, Date date, int page, int size) {
      List<Player> playerList = this.playerDao.getPlayerList(yx, date, page, size);
      if (playerList != null && playerList.size() > 0) {
         List<YxSourceInfo> yxSourceInfoList = new ArrayList();
         Iterator var8 = playerList.iterator();

         while(var8.hasNext()) {
            Player player = (Player)var8.next();
            yxSourceInfoList.add(new YxSourceInfo(player.getUserId(), player.getPlayerId(), player.getPlayerName(), player.getPlayerLv(), player.getLoginTime()));
         }

         return yxSourceInfoList;
      } else {
         return new ArrayList();
      }
   }

   public int queryPlayerYxSourceSize(String yx, Date date) {
      return this.playerDao.getSizeByYxAndDate(yx, date);
   }

   public int getOnlinePlayersNumber(String yx) {
      return Players.getOnlinePlayersNumber(yx);
   }

   public YxPlayerInfo getPlayerById(int playerId) {
      Player player = this.playerDao.read(playerId);
      return player == null ? null : new YxPlayerInfo(playerId, player.getPlayerName(), player.getState(), player.getPlayerLv(), player.getForceId(), player.getUserId(), player.getCreateTime());
   }

   public int getDailyOnlineTime(int playerId) {
      int result = this.playerDao.getDailyOnlineTime(playerId);
      PlayerDto dto = Players.getPlayer(playerId);
      if (dto != null) {
         result += (int)((System.currentTimeMillis() - dto.loginTime) / 1000L);
      }

      return result;
   }

   public YxPlayerPayInfo queryOrder(String orderId, String yx) {
      PlayerPay p = this.playerPayDao.queryOrder(orderId, yx);
      return p == null ? null : new YxPlayerPayInfo(p.getUserId(), p.getOrderId(), p.getGold(), p.getType(), p.getCreateTime(), p.getPlayerId());
   }

   public List<YxPlayerPayInfo> queryOrderByDateAndPage(Date startTime, Date endTime, int page, int size, String yx) {
      List<PlayerPay> ppList = this.playerPayDao.getPlayerPayByDateAndPage(startTime, endTime, (page - 1) * size, size, yx);
      if (ppList == null) {
         return null;
      } else {
         List<YxPlayerPayInfo> ppiList = new ArrayList();
         Iterator var9 = ppList.iterator();

         while(var9.hasNext()) {
            PlayerPay p = (PlayerPay)var9.next();
            ppiList.add(new YxPlayerPayInfo(p.getUserId(), p.getOrderId(), p.getGold(), p.getType(), p.getCreateTime(), p.getPlayerId()));
         }

         return ppiList;
      }
   }

   public boolean banChat(String userIds, int keepTime, String yx) {
      boolean result = false;
      String[] userIdArr = userIds.split(",");
      Date nextSayTime = TimeUtil.nowAddMinutes(keepTime);
      Date nowDate = new Date();

      for(int i = 0; i < userIdArr.length; ++i) {
         String userId = userIdArr[i];
         List<Player> playerList = this.playerDao.getPlayerByUserId(userId, yx);

         for(Iterator var12 = playerList.iterator(); var12.hasNext(); result = true) {
            Player player = (Player)var12.next();
            int playerId = player.getPlayerId();
            Silence silence = this.silenceDao.getByPlayerId(playerId);
            if (silence != null) {
               silence.setNextSayTime(nextSayTime);
               silence.setSilenceTime(nowDate);
               silence.setReason("");
               silence.setType(1);
               this.silenceDao.update(silence);
            } else {
               silence = new Silence();
               silence.setNextSayTime(nextSayTime);
               silence.setPlayerId(playerId);
               silence.setReason("");
               silence.setSilenceTime(nowDate);
               silence.setUserId(player.getUserId());
               silence.setYx(yx);
               silence.setType(1);
               this.silenceDao.create(silence);
            }
         }
      }

      return result;
   }

   public boolean unbanChat(String userIds, String yx) {
      boolean result = false;
      String[] userIdArr = userIds.split(",");
      Date nowDate = new Date();

      for(int i = 0; i < userIdArr.length; ++i) {
         String userId = userIdArr[i];
         List<Player> playerList = this.playerDao.getPlayerByUserId(userId, yx);
         Iterator var10 = playerList.iterator();

         while(var10.hasNext()) {
            Player player = (Player)var10.next();
            int playerId = player.getPlayerId();
            Silence silence = this.silenceDao.getByPlayerId(playerId);
            if (silence.getType() != 2) {
               silence.setNextSayTime(nowDate);
               this.silenceDao.update(silence);
               result = true;
            }
         }
      }

      return result;
   }

   public boolean banUser(String userIds, String yx) {
      boolean result = false;
      Date endDate = TimeUtil.nowAddHours(this.TEN_YEARS_HOURS);
      String[] userIdArr = userIds.split(",");

      for(int i = 0; i < userIdArr.length; ++i) {
         String userId = userIdArr[i];
         List<Player> playerList = this.playerDao.getPlayerByUserId(userId, yx);
         Iterator var10 = playerList.iterator();

         while(var10.hasNext()) {
            Player player = (Player)var10.next();
            List<UserBlock> ubList = this.userBlockDao.getUserBlock(player.getUserId(), yx);
            UserBlock ub;
            if (ubList != null && ubList.size() > 0) {
               Iterator var13 = ubList.iterator();

               while(var13.hasNext()) {
                  ub = (UserBlock)var13.next();
                  this.userBlockDao.update(ub.getVId(), "", endDate);
               }
            } else {
               ub = new UserBlock();
               ub.setBlockEndTime(endDate);
               ub.setPlayerId(player.getPlayerId());
               ub.setUserId(player.getUserId());
               ub.setYx(yx);
               ub.setReason("");
               this.userBlockDao.create(ub);
            }

            result = true;
            AuthInterceptor.blockPlayer(player.getUserId(), yx, endDate.getTime(), "");
         }
      }

      return result;
   }

   public boolean unbanUser(String userIds, String yx) {
      boolean result = false;
      String[] userIdArr = userIds.split(",");

      label36:
      for(int i = 0; i < userIdArr.length; ++i) {
         String userId = userIdArr[i];
         List<Player> playerList = this.playerDao.getPlayerByUserId(userId, yx);
         Iterator var9 = playerList.iterator();

         while(true) {
            Player player;
            List ubList;
            do {
               if (!var9.hasNext()) {
                  continue label36;
               }

               player = (Player)var9.next();
               ubList = this.userBlockDao.getUserBlock(player.getUserId(), yx);
            } while(ubList == null);

            Iterator var12 = ubList.iterator();

            while(var12.hasNext()) {
               UserBlock ub = (UserBlock)var12.next();
               if (ub.getPlayerId() == player.getPlayerId()) {
                  this.userBlockDao.deleteById(ub.getVId());
                  AuthInterceptor.unblockPlayer(player.getUserId(), yx);
                  result = true;
               }
            }
         }
      }

      return result;
   }

   public List<YxNoticeInfo> queryNotice(String yx) {
      List<SystemNotice> list = this.systemNoticeDao.getModels();
      List<YxNoticeInfo> ynList = new ArrayList();
      Date now = new Date();
      Iterator var6 = list.iterator();

      while(var6.hasNext()) {
         SystemNotice sn = (SystemNotice)var6.next();
         if (sn.getYx().equalsIgnoreCase(yx) && sn.getStartTime().before(now) && sn.getExpireTime().after(now)) {
            ynList.add(new YxNoticeInfo(sn.getContent()));
         }
      }

      return ynList;
   }

   public Tuple<Boolean, Integer> modifyUserId(String yx, String oldUserId, String newUserId) {
      Tuple<Boolean, Integer> tuple = new Tuple();
      tuple.left = false;
      List<Player> oldList = this.playerDao.getPlayerByUserId(oldUserId, yx);
      if (oldList.size() < 1) {
         tuple.right = 1011;
         return tuple;
      } else {
         this.playerDao.modifyUserId(yx, oldUserId, newUserId);
         Iterator var7 = oldList.iterator();

         while(var7.hasNext()) {
            Player player = (Player)var7.next();
            int playerId = player.getPlayerId();
            PlayerDto dto = (PlayerDto)Players.playerMap.get(playerId);
            if (dto != null) {
               dto.userId = newUserId;
            }

            Iterator var11 = Players.sessionPlayerMap.values().iterator();

            while(var11.hasNext()) {
               PlayerDto playerDto = (PlayerDto)var11.next();
               if (playerDto.playerId == playerId) {
                  playerDto.userId = newUserId;
               }
            }
         }

         String oldId = oldUserId + "-" + yx;
         String newId = newUserId + "-" + yx;
         UserDto userDto1 = (UserDto)Users.userMap.remove(oldId);
         if (userDto1 != null) {
            userDto1.userId = newUserId;
            userDto1.setId(newId);
            Users.userMap.put(newId, userDto1);
         }

         Session session = (Session)Users.userSessionMap.remove(oldId);
         if (session != null) {
            Users.userSessionMap.put(newId, session);
         }

         UserDto userDto2 = (UserDto)Users.sessionUserMap.remove(oldId);
         if (userDto2 != null) {
            userDto2.userId = newUserId;
            userDto2.setId(newId);
            Users.sessionUserMap.put(newId, userDto2);
         }

         tuple.left = true;
         return tuple;
      }
   }

   public boolean checkEmptyParams(Map<String, String> map, Request request, String yx) {
      long start = System.currentTimeMillis();
      Iterator var7 = map.keySet().iterator();

      String key;
      String value;
      do {
         if (!var7.hasNext()) {
            return false;
         }

         key = (String)var7.next();
         value = (String)map.get(key);
      } while(!StringUtils.isBlank(value));

      opReport.info(OpLogUtil.formatOpInterfaceLog("yx" + yx, "yx" + yx + "_fail_" + key + "_IS_EMPTY", YxHelper.getIp(request), request.getParamterMap(), request.getContent(), false, System.currentTimeMillis() - start, new ByteResult(BackstageUtil.returnError(1100)), 1100));
      return true;
   }

   public String exeTencentQuery(String yx, Map<String, Object> paramMap, String baseUrl, String uri, String method, boolean isHttps, boolean isCallBack) {
      opReport.error("#start executing.....");
      String appKey = PluginContext.configuration.getTencentAppKey(yx);
      String sig = this.getOpenAPISign(uri, paramMap, appKey, method, isCallBack);
      paramMap.put("sig", sig);
      opReport.error("#sign:" + sig);
      String echo = "";

      try {
         String requestURL = WebUtils.getURL(baseUrl + uri, paramMap);
         requestURL = requestURL.replace("*", "%2A");
         opReport.error("query URL:" + requestURL);
         if (isHttps) {
            echo = WebUtils.sendSSLGetRequest(requestURL, paramMap);
         } else {
            echo = WebUtils.sendRequest(requestURL, paramMap);
         }
      } catch (UnsupportedEncodingException var12) {
         UnsupportedEncodingException var12 = var12;
         var12.printStackTrace();
         opReport.error("#YxOperation#exeTencentQuery#UnsupportedEncodingException:" + echo);
      }

      opReport.error("echo:" + echo);
      return echo;
   }

   public String getOpenAPISign(String uri, Map<String, Object> paramMap, String appkey, String method, boolean isCallBack) {
      List<String> keyList = new ArrayList(paramMap.keySet());
      Collections.sort(keyList);
      StringBuffer sb = new StringBuffer();
      Iterator var9 = keyList.iterator();

      while(true) {
         while(true) {
            String key;
            do {
               if (!var9.hasNext()) {
                  if (method == null || method.isEmpty()) {
                     method = "POST";
                  }

                  key = method + "&";

                  try {
                     key = key + URLEncoder.encode(uri, "UTF-8") + "&" + URLEncoder.encode(sb.toString(), "UTF-8");
                     opReport.error("source:" + key);
                     key = key.replace("*", "%2A");
                  } catch (UnsupportedEncodingException var17) {
                     var17.printStackTrace();
                     return null;
                  }

                  try {
                     return Coder.encryptBASE64(HMAC_SHA1.getHmacSHA1(key, appkey + "&")).trim();
                  } catch (Exception var16) {
                     var16.printStackTrace();
                     return null;
                  }
               }

               key = (String)var9.next();
            } while(key.equals("sig"));

            if (sb.length() > 0) {
               sb.append("&");
            }

            sb.append(key);
            sb.append("=");
            if (isCallBack && key.equals("billno")) {
               String value = paramMap.get(key).toString();
               char[] charArray = value.toCharArray();

               for(int i = 0; i < charArray.length; ++i) {
                  char asciiIntForV;
                  char v = asciiIntForV = charArray[i];
                  if (asciiIntForV >= '0' && asciiIntForV <= '9' || asciiIntForV == '!' || asciiIntForV >= '(' && asciiIntForV <= '*' || asciiIntForV >= 'A' && asciiIntForV <= 'Z' || asciiIntForV >= 'a' && asciiIntForV <= 'z') {
                     sb.append(v);
                  } else {
                     String asciiForV = Integer.toHexString(asciiIntForV).toUpperCase();
                     sb.append("%");
                     sb.append(asciiForV);
                  }
               }
            } else {
               sb.append(paramMap.get(key));
            }
         }
      }
   }

   public void setTencentPayMap(Map<String, YxTencentPayInfo> tencentPayMap) {
      YxOperation.tencentPayMap = tencentPayMap;
   }

   public Map<String, YxTencentPayInfo> getTencentPayMap() {
      return tencentPayMap;
   }

   public void removeTencentPayMap(String key) {
      tencentPayMap.remove(key);
   }

   public boolean checkTencentPf(String pf) {
      pf = pf.replace("_m", "");
      return pf.equals("pengyou") || pf.equals("qzone") || pf.equals("3366");
   }

   public Tuple<Integer, Integer> rewardWX(int playerId, String userId, String yx) {
      Tuple<Integer, Integer> tuple = new Tuple();
      if (playerId <= 0) {
         playerId = this.getDefaultPayPlayer(userId, yx);
      }

      Player player = this.playerDao.read(playerId);
      if (player == null) {
         tuple.left = 2;
         tuple.right = 2;
         return tuple;
      } else if (player.getUserId().equalsIgnoreCase(userId) && player.getYx().equals(yx)) {
         label76: {
            Tuple var8;
            try {
               Constants.locks[playerId % Constants.LOCKS_LEN].lock();
               PlayerTaobao playerTaobao = this.playerTaobaoDao.read(player.getPlayerId());
               if (playerTaobao == null) {
                  playerTaobao = new PlayerTaobao();
                  playerTaobao.setPlayerId(player.getPlayerId());
                  this.playerTaobaoDao.create(playerTaobao);
                  break label76;
               }

               tuple.left = 5;
               tuple.right = 5;
               var8 = tuple;
            } catch (Exception var11) {
               Exception var11 = var11;
               errorLog.error(this, var11);
               break label76;
            } finally {
               Constants.locks[playerId % Constants.LOCKS_LEN].unlock();
            }

            return var8;
         }

         this.playerResourceDao.addCopperIgnoreMax(playerId, 20000.0, "旺信大礼包获取银币", false);
         this.playerResourceDao.addFoodIgnoreMax(playerId, 20000.0, "旺信大礼包获取粮食");
         this.playerResourceDao.addWoodIgnoreMax(playerId, 20000.0, "旺信大礼包获取木材", false);
         tuple.left = 1;
         tuple.right = 1;
         return tuple;
      } else {
         tuple.left = 3;
         tuple.right = 3;
         return tuple;
      }
   }

   public int getAllPlayerNumber() {
      return this.playerDao.getModelSize();
   }

   public List<PingAnPlayerInfo> queryPlayerInfo(String customer, String yx, String gatewayId) {
      List<Player> playerList = this.playerDao.getPlayerNoDeleteByUserIdAndYx(customer, yx);
      List<PingAnPlayerInfo> result = new ArrayList();
      PingAnPlayerInfo info = null;
      Iterator var8 = playerList.iterator();

      while(var8.hasNext()) {
         Player cell = (Player)var8.next();
         info = new PingAnPlayerInfo();
         info.roleName = cell.getPlayerName();
         info.roleLever = "" + cell.getPlayerLv();
         info.roleServer = gatewayId;
         info.roleCoin = "" + cell.getSysGold();
         result.add(info);
      }

      return result;
   }

   public PingAnMoneyInfo queryMoneyInfo(String customer, String yx) {
      List<Player> players = this.playerDao.getPlayerByUserId(customer, yx);
      int sum = 0;

      Player player;
      for(Iterator var6 = players.iterator(); var6.hasNext(); sum += player.getSysGold()) {
         player = (Player)var6.next();
      }

      PingAnMoneyInfo info = new PingAnMoneyInfo();
      info.avaliableGameAmount = String.valueOf(sum);
      return info;
   }

   public int test360Privilege(String uId, int level) {
      return this.activityService.recv360PrivilegeForTest(uId, level);
   }
}
